# Originally imported from rosa

%define api 1.10
%define major 1
%define libname %mklibname %{name} %{api} %{major}
%define devname %mklibname %{name} %{api} -d

Summary:	Crypto library written in C++
Name:		botan
Version:	1.10.17
Release:	%mkrel 1
License:	BSD
Group:		Development/Libraries
Url:		http://botan.randombit.net/
Source0:	http://botan.randombit.net/releases/Botan-%{version}.tar.xz
Patch0:		Botan-1.10.17-cstdint.patch
BuildRequires:	bzip2-devel
BuildRequires:	gmp-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library.

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Main library for %{name}
Group:		System/Libraries

%description -n %{libname}
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library.

%files -n %{libname}
%{_libdir}/libbotan-%{api}.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}

%description -n %{devname}
This package contains libraries and header files for developing applications
that use %{name}.

%files -n %{devname}
%doc _doc/readme.txt
%doc doc/examples
%{_includedir}/%{name}-%{api}/
%{_bindir}/botan-config-%{api}
%{_libdir}/libbotan-%{api}.so
%{_libdir}/pkgconfig/%{name}-%{api}.pc

#----------------------------------------------------------------------------

%prep
%setup -qn Botan-%{version}
%apply_patches

# Update permissions for debuginfo package
find . -name "*.c" -o -name "*.h" -o -name "*.cpp" |xargs chmod 0644

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules gnump,bzip2,zlib,openssl

# fixme: maybe disable unix_procs, very slow.
%define disable_modules %{nil}

./configure.py \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --enable-modules=%{enable_modules} \
        --disable-modules=%{disable_modules}

# (ab)using CXX as an easy way to inject our CXXFLAGS
make CXX="g++ ${CXXFLAGS:-%{optflags}} -std=gnu++11" %{?_smp_mflags}

%install
make install \
	DESTDIR=%{buildroot}%{_prefix} \
	DOCDIR=_doc \
	INSTALL_CMD_EXEC="install -p -m 755" \
	INSTALL_CMD_DATA="install -p -m 644" \

rm -f %{buildroot}%{_libdir}/*.a

%check
make CXX="g++ ${CXXFLAGS:-%{optflags}}" %{?_smp_mflags} check

# these checks would fail
mv checks/validate.dat{,.orig}
awk '/\[.*\]/{f=0} /\[(RC5.*|RC6|IDEA)\]/{f=1} (f && !/^#/){sub(/^/,"#")} {print}' \
    checks/validate.dat.orig > checks/validate.dat
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./check --validate


%changelog
* Tue Oct 09 2018 adrianomorselli <adrianomorselli> 1.10.17-1uplos2018
- impoprted for uplos
